<?php
/**
* @package phpBB Extension - Extension Credits
* @copyright (c) 2022 Sniper_E - https://www.sniper-e.net
* @license http://opensource.org/licenses/gpl-2.0.php GNU General Public License v2
*/

namespace sniper\extcredits\event;

use Symfony\Component\EventDispatcher\EventSubscriberInterface;
use phpbb\request\request_interface;
use phpbb\template\template;
use phpbb\user;

class listener implements EventSubscriberInterface
{
	/** @var request_interface  */
	protected $request;
	
	/* @var template */
	protected $template;

	/* @var user */
	protected $user;

	/** @var \phpbb\extension\manager */
	protected $extension_manager;
	
	/**
	* Constructor
	*
	* @param request_interface	        $request
	* @param template                   $template
	* @param user                       $user
	* @param \phpbb\extension\manager 	$extension_manager
	*
	*/
	public function __construct(
		request_interface $request, 
		template $template, 
		user $user,
		\phpbb\extension\manager $extension_manager
	)
	{
		$this->request           = $request;
		$this->template          = $template;
		$this->user              = $user;
		$this->extension_manager = $extension_manager;
	}

	static public function getSubscribedEvents()
	{
		return array(
			'core.user_setup'                 => 'load_language_on_setup',
			'core.page_header'                => 'page_header',
			'core.ucp_prefs_view_data'        => 'ucp_prefs_view_data',
			'core.ucp_prefs_view_update_data' => 'ucp_prefs_view_update_data',
		);
	}

	public function load_language_on_setup($event)
	{
		$lang_set_ext = $event['lang_set_ext'];
		$lang_set_ext[] = array(
			'ext_name' => 'sniper/extcredits',
			'lang_set' => 'extcredits',
		);
		$event['lang_set_ext'] = $lang_set_ext;
	}

	public function page_header($event)
	{
		$md_manager = $this->extension_manager->create_extension_metadata_manager('sniper/extcredits', $this->template);
		$meta = $md_manager->get_metadata();
		$author_homepages = array();

		foreach (array_slice($meta['authors'], 0, 1) as $author)
		{
			$author_homepages[] = sprintf('<a href="%1$s" title="%2$s &bull; %1$s" target="_blank">%3$s</a>', $author['homepage'], $author['sitename'], $author['name']);
		}

		$this->template->assign_vars(array(
			'S_WRAPEXTS'                  => !empty($this->user->data['user_extcredits_wrapexts']) ? true : false,
			'S_WRAPSTATS'                 => !empty($this->user->data['user_extcredits_wrapstats']) ? true : false,
			'EXTCREDITS_DISPLAY_NAME'     => $meta['extra']['display-name'],
			'EXTCREDITS_DISCRIPTION'      => $meta['description'],
			'EXTCREDITS_VERSION'          => $meta['version'],
			'EXTCREDITS_TOPIC'            => $meta['extra']['topicpage'],
			'EXTCREDITS_SITENAME'         => $author['sitename'],
			'EXTCREDITS_HOMEPAGE'         => $author['homepage'],
			'EXTCREDITS_AUTHOR_HOMEPAGES' => implode(' &amp; ', $author_homepages),
		));
	}
	
	public function ucp_prefs_view_data($event)
	{
		$event['data'] = array_merge($event['data'], array(
			'extcredits_wrapexts'  => $this->request->variable('extcredits_wrapexts', (int) $this->user->data['user_extcredits_wrapexts']),
			'extcredits_wrapstats' => $this->request->variable('extcredits_wrapstats', (int) $this->user->data['user_extcredits_wrapstats']),
		));

		if (!$event['submit'])
		{
			$this->template->assign_vars(array(
				'S_UCP_WRAPEXTS'  => $event['data']['extcredits_wrapexts'],
				'S_UCP_WRAPSTATS' => $event['data']['extcredits_wrapstats'],
			));
		}
	}

	public function ucp_prefs_view_update_data($event)
	{
		$event['sql_ary'] = array_merge($event['sql_ary'], array(
			'user_extcredits_wrapexts'  => $event['data']['extcredits_wrapexts'],
			'user_extcredits_wrapstats' => $event['data']['extcredits_wrapstats'],
		));
	}
}
